%define anolis_release 5

Name:           attr
Version:        2.5.1
Release:        %{anolis_release}%{?dist}
Summary:        Utilities for managing filesystem extended attributes

License:        GPLv2+
URL:            https://savannah.nongnu.org/projects/attr
Source0:        https://download-mirror.savannah.gnu.org/releases/attr/attr-%{version}.tar.xz

Patch0:         0001-attr-2.5.1-eliminate-dead-store.patch
Patch1:         0002-fix-incompatibility_with_autoconf.patch

BuildRequires:  gettext
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  perl(FileHandle)
Requires:       libattr = %{version}-%{release}

%description
A set of tools for manipulating extended attributes on filesystem
objects, in particular getfattr(1) and setfattr(1).
An attr(1) command is also provided which is largely compatible
with the SGI IRIX tool of the same name.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package -n libattr
Summary: Dynamic library for extended attribute support
License: LGPLv2+

%description -n libattr
This package contains the libattr.so dynamic library which contains
the extended attribute system calls and library functions.

%package -n libattr-devel
Summary: Files needed for building programs with libattr
License: LGPLv2+
Requires: libattr = %{version}-%{release}

# for <sys/xattr.h> which <attr/xattr.h> is symlinked to
Requires: glibc-headers

# provides {,f,l}{get,list,remove,set}xattr.2 man pages
Recommends: man-pages

%description -n libattr-devel
This package contains header files and documentation needed to
develop programs which make use of extended attributes.
For Linux programs, the documented system call API is the
recommended interface, but an SGI IRIX compatibility interface
is also provided.

Currently only ext2, ext3, ext4 and XFS support extended attributes.
The SGI IRIX compatibility API built above the Linux system calls is
used by programs such as xfsdump(8), xfsrestore(8) and xfs_fsr(8).

You should install libattr-devel if you want to develop programs
which make use of extended attributes.  If you install libattr-devel,
you'll also want to install attr.

%prep
%autosetup -p1

%build
%configure
%make_build

%check
if ./setfattr -n user.name -v value .; then
    make check || exit $?
else
    echo '*** xattrs are probably not supported by the file system,' \
         'the test-suite will NOT run ***'
fi

%install
%make_install

# remove libattr.a and libattr.la
find %{buildroot}%{_libdir} -maxdepth 1 -type f \
  \( -name "*.a" -or -name '*.la' \) -delete -print

# handle docs on our own
rm -rf %{buildroot}/%{_datadir}/doc/%{name}

ln -fs ../sys/xattr.h %{buildroot}%{_includedir}/attr/xattr.h

%find_lang %{name}

%generate_compatibility_deps

%files -f %{name}.lang
%license doc/COPYING*
%{_bindir}/attr
%{_bindir}/getfattr
%{_bindir}/setfattr
%{abidir}/getfattr-option.list
%{abidir}/setfattr-option.list
%{_mandir}/man1/attr.1*
%{_mandir}/man1/getfattr.1*
%{_mandir}/man1/setfattr.1*

%files doc
%doc doc/CHANGES

%files -n libattr-devel
%{_libdir}/libattr.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/attr
%{_mandir}/man3/attr_*.3.*

%files -n libattr
%dir %{abidir}
%{_libdir}/libattr.so.*
%{abidir}/libattr.dump
%config(noreplace) %{_sysconfdir}/xattr.conf

%changelog
* Tue Apr 4 2023 yuanhui <yuanhui@linux.alibaba.com> 2.5.1-5
- provides attr/xattr.h

* Thu Nov 17 2022 chen_yu_ao <m15927509890@163.com> - 2.5.1-4
- add patch 0001: eliminate a dead store in attr_copy_action()
- add patch 0002: fix incompatibility with autoconf 2.12

* Wed Nov 02 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.5.1-3
- optimise spec file 

* Sun Oct 09 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.5.1-2
- add doc package

* Thu Mar 03 2022 Su Lifan <su-lifan@linux.alibaba.com> - 2.5.1-1
- Initial packaging for Anolis OS 23
